Providers
=========


``aws``
---------

.. autofunction:: notify.providers.aws.aws.Aws


``dummy``
-------------

.. autofunction:: notify.providers.dummy.dummy.Dummy 


``email``
----------

.. autofunction:: notify.providers.email.email.Email


``gmail``
-----------

.. autofunction:: notify.providers.gmail.gmail.Gmail


``office365``
--------------

.. autofunction:: notify.providers.office365.office365.Office365


``onesignal``
--------------

.. autofunction:: notify.providers.onesignal.onesignal.Onesignal


``sendgrid``
-------------

.. autofunction:: notify.providers.sendgrid.sendgrid.Sendgrid


``slack``
------------

.. autofunction:: notify.providers.slack.slack.Slack


``telegram``
-------------

.. autofunction:: notify.providers.telegram.telegram.Telegram


``twilio``
------------

.. autofunction:: notify.providers.twilio.twilio.Twilio


``twitter``
------------

.. autofunction:: notify.providers.twitter.twitter.Twitter


``xmpp``
------------

.. autofunction:: notify.providers.xmpp.xmpp.Xmpp